Package: qqplotr
Type: Package
Version: 0.0.7
Title: Quantile-Quantile Plot Extensions for 'ggplot2'
Description: Extensions of 'ggplot2' Q-Q plot functionalities.
Authors@R: c(person("Alexandre", "Almeida", email = "almeida.xan@gmail.com", role = c("aut")),
		person("Adam", "Loy", email = "loyad01@gmail.com", role = c("aut", "cre")),
    person("Heike", "Hofmann", role = "aut"))
URL: https://github.com/aloy/qqplotr
BugReports: https://github.com/aloy/qqplotr/issues
License: GPL-3 | file LICENSE
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.2
Collate: 'data.R' 'geom_qq_band.R' 'qqplotr.R' 'runShinyExample.R'
        'stat_pp_band.R' 'stat_pp_line.R' 'stat_pp_point.R'
        'stat_qq_line.R' 'stat_qq_band.R' 'stat_qq_point.R'
VignetteBuilder: knitr
Depends: R (>= 3.1), ggplot2 (>= 2.2)
Imports: dplyr, robustbase, MASS, opdisDownsampling, qqconf (>= 1.3.1)
Suggests: shiny, devtools, lattice, shinyBS, knitr, rmarkdown
NeedsCompilation: no
Packaged: 2025-09-05 01:14:45 UTC; aloy
Author: Alexandre Almeida [aut],
  Adam Loy [aut, cre],
  Heike Hofmann [aut]
Maintainer: Adam Loy <loyad01@gmail.com>
Repository: CRAN
Date/Publication: 2025-09-05 17:00:02 UTC
Built: R 4.6.0; ; 2026-04-26 11:30:12 UTC; unix
