# Generated by roxygen2: do not edit by hand

export(GeomQqBand)
export(StatPpBand)
export(StatPpLine)
export(StatPpPoint)
export(StatQqBand)
export(StatQqLine)
export(StatQqPoint)
export(geom_qq_band)
export(runShinyExample)
export(stat_pp_band)
export(stat_pp_line)
export(stat_pp_point)
export(stat_qq_band)
export(stat_qq_line)
export(stat_qq_point)
import(ggplot2)
importFrom(MASS,fitdistr)
importFrom(dplyr,group_by)
importFrom(dplyr,summarize)
importFrom(opdisDownsampling,opdisDownsampling)
importFrom(qqconf,get_qq_band)
importFrom(robustbase,Qn)
importFrom(robustbase,s_Qn)
